@@ -58,8 +58,8 @@ call_NSInvocation_setArgument_atIndex_(PyObject* method, PyObject* self,
                     PyObjCObject_GetObject(self), PyObjCIMP_GetSelector(method), buf,
                     index);
             } else {
-                PyObjC_InitSuper(&super, PyObjCSelector_GetClass(method),
-                                 PyObjCObject_GetObject(self));
+                super.super_class = PyObjCSelector_GetClass(method);
+                super.receiver    = PyObjCObject_GetObject(self);
 
                 ((void (*)(struct objc_super*, SEL, void*, NSUInteger))objc_msgSendSuper)(
                     &super, PyObjCSelector_GetSelector(method), buf, index);
@@ -134,8 +134,8 @@ call_NSInvocation_setReturnValue_(PyObject* method, PyObject* self,
                 ((void (*)(id, SEL, void*))(PyObjCIMP_GetIMP(method)))(
                     PyObjCObject_GetObject(self), PyObjCIMP_GetSelector(method), buf);
             } else {
-                PyObjC_InitSuper(&super, PyObjCSelector_GetClass(method),
-                                 PyObjCObject_GetObject(self));
+                super.super_class = PyObjCSelector_GetClass(method);
+                super.receiver    = PyObjCObject_GetObject(self);
 
                 ((void (*)(struct objc_super*, SEL, void*))objc_msgSendSuper)(
                     &super, PyObjCSelector_GetSelector(method), buf);
@@ -214,8 +214,8 @@ call_NSInvocation_getArgument_atIndex_(PyObject* method, PyObject* self,
                     PyObjCObject_GetObject(self), PyObjCIMP_GetSelector(method), buf,
                     index);
             } else {
-                PyObjC_InitSuper(&super, PyObjCSelector_GetClass(method),
-                                 PyObjCObject_GetObject(self));
+                super.super_class = PyObjCSelector_GetClass(method);
+                super.receiver    = PyObjCObject_GetObject(self);
 
                 ((void (*)(struct objc_super*, SEL, void*, NSUInteger))objc_msgSendSuper)(
                     &super, PyObjCSelector_GetSelector(method), buf, index);
@@ -294,8 +294,8 @@ call_NSInvocation_getReturnValue_(PyObject* method, PyObject* self,
                 ((void (*)(id, SEL, void*))(PyObjCIMP_GetIMP(method)))(
                     PyObjCObject_GetObject(self), PyObjCIMP_GetSelector(method), buf);
             } else {
-                PyObjC_InitSuper(&super, PyObjCSelector_GetClass(method),
-                                 PyObjCObject_GetObject(self));
+                super.super_class = PyObjCSelector_GetClass(method);
+                super.receiver    = PyObjCObject_GetObject(self);
 
                 ((void (*)(struct objc_super*, SEL, void*))objc_msgSendSuper)(
                     &super, PyObjCSelector_GetSelector(method), buf);
